@@ -196,6 +196,8 @@ void cmdline_start(char* str, int cursor, BOOL quick, BOOL continue_)
 
     gHistoryScrollTop = 0;
     gHistoryCursor = -1;
+
+    cmdline_convert();
 }
 
 ///////////////////////////////////////////////////
@@ -215,13 +217,36 @@ static void cursor_move(int v)
     gCmdLineCursor = str_kanjipos2pointer(kUtf8, str, utfpos) - str;
 }
 
+void cmdline_convert()
+{
+    if(gKanjiCodeFileName != gKanjiCode) {
+        char* src = string_c_str(gCmdLine);
+        char* des = MALLOC(strlen(src)*2);
+        int des_size = strlen(src)*2;
+#if defined(HAVE_ICONV_H) || defined(HAVE_BICONV_H) 
+        if(is_all_ascii(src)) {
+            strcpy(des, src);
+        }
+        else {
+            /// コンバート ///
+            if(kanji_convert(src, des, des_size, gKanjiCodeFileName, gKanjiCode) < 0) {
+                strcpy(des, src);
+            }
+        }
+#else
+        strcpy(des, src);
+#endif
+        string_put(gCmdLine, des);
+        FREE(des);
+    }
+}
+
 void cmdline_input(int meta, int key)
 {
     BOOL kanji[kCmdLineMax];
     char* p = string_c_str(gCmdLine);
     int len = strlen(p);
     int i;
-
     char* env = getenv("CMDLINE_ESCAPE_KEY_ENABLE");
 
     BOOL cmdline_escape_key = env && strcmp(env, "1") == 0;
@@ -628,6 +653,8 @@ void cmdline_input(int meta, int key)
             gCmdLineCursor = strlen(string_c_str(gCmdLine));
         }
     }
+
+    cmdline_convert();
 }
 
 void cmdline_hcandidate_refresh()
@@ -922,7 +949,7 @@ static void cmdline_view_filer()
     }
 
     char size_buf[256];
-    int width = make_size_str(size_buf, file->mLStat.st_size);
+    int width = filer_make_size_str(size_buf, file->mLStat.st_size);
 
     if(S_ISDIR(file->mStat.st_mode)) {
         strcpy(size_buf, "<DIR>");
