@@ -120,24 +120,58 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
     char* cstr = string_c_str(str);
 
     /// go ///
-    gCompletionAddSpace = add_space;
+    vector_obj* all_candidate2 = VECTOR_NEW(50);
 
-    gEditingLen = strlen(editing);
-    strcpy(gEditing, editing);
-
-    cmdline_completion_clear();
-
-    if(strcmp(editing, "") == 0) {
+    if(gKanjiCode != gKanjiCodeFileName) {
         int i;
         for(i=0; i<vector_size(all_candidate); i++) {
             string_obj* str = vector_item(all_candidate, i);
-            vector_add(gCCandidate , STRING_NEW(string_c_str(str)));
+
+            char* src = string_c_str(str);
+            char* des = MALLOC(strlen(src)*2);
+            int des_size = strlen(src)*2;
+#if defined(HAVE_ICONV_H) || defined(HAVE_BICONV_H) 
+            if(is_all_ascii(src)) {
+                strcpy(des, src);
+            }
+            else {
+                /// コンバート ///
+                if(kanji_convert(src, des, des_size, gKanjiCodeFileName, gKanjiCode) < 0) {
+                    strcpy(des, src);
+                }
+            }
+#else
+            strcpy(des, src);
+#endif
+            vector_add(all_candidate2, STRING_NEW(des));
+            FREE(des);
         }
     }
     else {
         int i;
         for(i=0; i<vector_size(all_candidate); i++) {
-            char* item = string_c_str(vector_item(all_candidate, i));
+            string_obj* str = vector_item(all_candidate, i);
+            vector_add(all_candidate2, STRING_NEW(string_c_str(str)));
+        }
+    }
+
+    gCompletionAddSpace = add_space;
+    strcpy(gEditing, editing);
+    gEditingLen = strlen(gEditing);
+
+    cmdline_completion_clear();
+
+    if(strcmp(editing, "") == 0) {
+        int i;
+        for(i=0; i<vector_size(all_candidate2); i++) {
+            string_obj* str = vector_item(all_candidate2, i);
+            vector_add(gCCandidate , STRING_NEW(string_c_str(str)));
+        }
+    }
+    else {
+        int i;
+        for(i=0; i<vector_size(all_candidate2); i++) {
+            char* item = string_c_str(vector_item(all_candidate2, i));
 
             if(strstr(item, editing) == item) {
                 vector_add(gCCandidate, STRING_NEW(item));
@@ -243,6 +277,13 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
             cmdline_completion_clear();
         }
     }
+    cmdline_convert();
+
+    int i;
+    for(i=0; i<vector_size(all_candidate2); i++) {
+        string_delete(vector_item(all_candidate2, i));
+    }
+    vector_delete(all_candidate2);
 }
 
 ///////////////////////////////////////////////////
@@ -376,6 +417,7 @@ void cmdline_completion2(vector_obj* all_candidate, char* editing, BOOL add_spac
             cmdline_completion_clear();
         }
     }
+    cmdline_convert();
 }
 
 ///////////////////////////////////////////////////
@@ -1039,6 +1081,9 @@ void cmdline_completion_input(int meta, int key)
         cmdline_completion_clear();
         gCompletionCursor = -1;
         cmdline_hcandidate_refresh();
+
+        cmdline_convert();
+
         return;
     }
     else if(key == 4 || key == 22 || key == KEY_NPAGE) {    // CTRL-D CTRL-V
