@@ -225,13 +225,15 @@ BOOL commands_mcd(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
             *rcode = 0;
         }
         else {
-            filer_cd(dir, arg1);
-            *rcode = 0;
+            if(filer_cd(dir, arg1) >= 0) {
+                *rcode = 0;
+            }
         }
     }
     else if(vector_size(argv) == 1) {
-        filer_cd(dir, "~");
-        *rcode = 0;
+        if(filer_cd(dir, "~") >= 0) {
+            *rcode = 0;
+        }
     }
 
     /// フック ///
@@ -1719,14 +1721,14 @@ BOOL commands_mark(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
 BOOL commands_new_dir(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     int l;
-    string_obj* mask = NULL;
+    string_obj* mask = STRING_NEW(".+");
     BOOL dotdir_mask = FALSE;
     for(l=0; l<vector_size(argv); l++) {
         char* arg = string_c_str(vector_item(argv, l));
 
         if(strcmp(arg, "-m") == 0 && l+1 < vector_size(argv)) {
             char* darg = string_c_str(vector_item(argv, l+1));
-            mask = STRING_NEW(darg);
+            string_put(mask, darg);
 
             string_delete(vector_item(argv, l));
             vector_erase(argv, l);
@@ -1750,16 +1752,13 @@ BOOL commands_new_dir(int* rcode, vector_obj* argv, vector_obj* blocks, vector_o
 
     if(vector_size(argv) == 2) {
         char* dir = string_c_str(vector_item(argv, 1));
-        int dir2 = filer_new_dir(dir);
-        filer_set_dotdir_mask(dir2, dotdir_mask);
-        if(mask) {
-            filer_set_mask(dir2, string_c_str(mask));
+        int dir2 = filer_new_dir(dir, dotdir_mask, string_c_str(mask));
+        if(dir2 >= 0) {
+            *rcode = 0;
         }
-        filer_cd(dir2, dir);
-        *rcode = 0;
     }
 
-    if(mask) string_delete(mask);
+    string_delete(mask);
 
     return TRUE;
 }
@@ -2585,6 +2584,50 @@ BOOL commands_mrm(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj*
     return TRUE;
 }
 
+BOOL commands_kanjicode_file_name(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
+{
+    int j=0;
+    for(j=1; j<vector_size(argv); j++) {
+        char* item = string_c_str(vector_item(argv, j));
+/*
+        if(strcmp(item, "-s") == 0) {
+            gKanjiCodeFileName = kSjis;
+            *rcode = 0;
+            string_delete(vector_item(argv, j));
+            vector_erase(argv, j);
+            j--;
+            continue;
+        }
+        else if(strcmp(item, "-e") == 0) {
+            gKanjiCodeFileName = kEucjp;
+            *rcode = 0;
+            string_delete(vector_item(argv, j));
+            vector_erase(argv, j);
+            j--;
+            continue;
+        }
+*/
+        if(strcmp(item, "-w") == 0) {
+            gKanjiCodeFileName = kUtf8;
+            *rcode = 0;
+            string_delete(vector_item(argv, j));
+            vector_erase(argv, j);
+            j--;
+            continue;
+        }
+        else if(strcmp(item, "-m") == 0) {
+            gKanjiCodeFileName = kUtf8Mac;
+            *rcode = 0;
+            string_delete(vector_item(argv, j));
+            vector_erase(argv, j);
+            j--;
+            continue;
+        }
+    }
+
+    return TRUE;
+}
+
 BOOL commands_mtrashbox(int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, char* title, BOOL input)
 {
     if(!mis_raw_mode()) {
@@ -2967,6 +3010,7 @@ void commands_init()
     saphire_add_inner_command("line_max", commands_line_max);
     saphire_add_inner_command("adir", commands_adir);
     saphire_add_inner_command("sdir", commands_sdir);
+    saphire_add_inner_command("kanjicode_file_name", commands_kanjicode_file_name);
 }
 
 void commands_final()
