@@ -8,22 +8,26 @@
 
 #include <sys/stat.h>     // ↑のマクロを使ってコンパイルしないといけない
 #define stat64 stat
-#define __off64_t size_t
+#define __off64_t long long int
 #define lstat64 lstat
 #undef _LARGEFILE64_SOURCE
-#else
+#elif defined(__DARWIN__)
+
+#include <sys/stat.h>     // ↑のマクロを使ってコンパイルしないといけない
+#define stat64 stat
+#define __off64_t long long int
+#define lstat64 lstat
+#elif defined(__LINUX__)
 #define _LARGEFILE64_SOURCE      // サイズが大きいファイルを扱うために必要
 
 #include <sys/stat.h>     // ↑のマクロを使ってコンパイルしないといけない
 #include <linux/stat.h>
 
 #undef _LARGEFILE64_SOURCE
-#endif
 
 extern int lstat (__const char *__restrict __file,
     struct stat *__restrict __buf) __attribute__ ((__nothrow__)) __attribute__ ((__nonnull__ (1, 2)));
 
-#if defined(__LINUX__)
 extern int lstat64 (__const char *__restrict __file,
       struct stat64 *__restrict __buf)
      __attribute__ ((__nothrow__)) __attribute__ ((__nonnull__ (1, 2)));
@@ -56,8 +60,6 @@ extern ssize_t readlink (__const char *__restrict __path,
 # endif
 #endif
 
-#include "config.h"
-
 #ifdef __LINUX__
 
 #include <linux/limits.h>
@@ -178,7 +180,7 @@ void isearch_final();        // インクリメンタルサーチ解放
 void isearch_input(int meta, int key); // インクリメンタルサーチキー入力
 void isearch_view();                  // インクリメンタルサーチ描写
 
-BOOL gISearchExplore;           // エキスプローラー風インクリメンタルサーチ
+extern BOOL gISearchExplore;           // エキスプローラー風インクリメンタルサーチ
 BOOL IsISearchExploreChar(int meta, int key);
 void isearch_explore_input(int meta, int key);
 void isearch_explore_view();
@@ -188,20 +190,21 @@ void ISearchClear();
 ///////////////////////////////////////////////////
 // cmdline
 ///////////////////////////////////////////////////
-BOOL gCmdLineActive;
-string_obj* gCmdLine;
-int gCmdLineCursor;
+extern BOOL gCmdLineActive;
+extern string_obj* gCmdLine;
+extern int gCmdLineCursor;
 #define kCmdLineMax 16000
 
 void cmdline_init();
 void cmdline_final();
 void cmdline_input(int meta, int key);
 void cmdline_view();
+void cmdline_convert();
 
-int gHistoryScrollTop;
-int gHistoryCursor;
+extern int gHistoryScrollTop;
+extern int gHistoryCursor;
 
-vector_obj* gHCandidate;
+extern vector_obj* gHCandidate;
 
 void cmdline_history_view();
 void cmdline_history_input(int meta, int key);
