@@ -59,47 +59,34 @@ extern BOOL gExtensionICase;        // マークファイルの拡張子別実
 void filer_init();
 void filer_final();
 
-int filer_new_dir(char* path);
+int filer_new_dir(char* path, BOOL dot_dir_mask, char* mask);
 void filer_del_dir(int dir);
 
-void filer_sort(int dir);
-
 sDir* filer_dir(int dir);
 sFile* filer_file(int dir, int num);
-int filer_file2(int dir, char* name);
+int filer_file2(int dir, char* name); // カーソル番号で返す
 ALLOC vector_obj* filer_mark_files(int dir);
+char* filer_mask(int dir);
+void filer_set_mask(int dir, char* mask);
+void filer_set_dotdir_mask(int dir, BOOL flg);
+BOOL filer_dotdir_mask(int dir);
+int filer_mark_file_num(int dir);
+BOOL filer_marking(int dir);
+int filer_cursor(int dir);
+sFile* filer_cursor_file(int dir);
+BOOL filer_mark(int dir, int num);
+void filer_set_mark(int dir, int num, int mark);
+
+void filer_sort(int dir);
 int filer_cd(int dir, char* path);
 int filer_cd_back(int dir);
 int filer_history_forward(int dir);
 int filer_history_back(int dir);
-
-char* filer_mask(int dir);
-
-void filer_set_mask(int dir, char* mask);
-void filer_set_dotdir_mask(int dir, BOOL flg);
-BOOL filer_dotdir_mask(int dir);
-
-void filer_vd_start(int dir);
-void filer_vd2_start(int dir);
-void filer_vd_add(int dir, char* fname);
-void filer_vd_add2(int dir, char* line);
-void filer_vd_end(int dir);
-BOOL filer_add_keycommand(int meta, int key, char* ftype, char* command, char* fname);
-
-void filer_archive_title(int dir, char* title);
-
 int filer_reread(int dir);
-int filer_mark_file_num(int dir);
-BOOL filer_marking(int dir);
 void filer_cursor_move(int dir, int num);
-int filer_cursor(int dir);
 void filer_activate(int dir);
 void filer_reset_marks(int dir);
-sFile* filer_cursor_file(int dir);
-
 void filer_toggle_mark(int dir, int num);
-BOOL filer_mark(int dir, int num);
-void filer_set_mark(int dir, int num, int mark);
 
 int filer_line(int dir);
 int filer_line_max(int dir);
@@ -108,11 +95,20 @@ int filer_row_max(int dir);
 
 void filer_view(int dir);
 void filer_input(int meta, int key);
+int filer_make_size_str(char* result, __off64_t size);
+
+void filer_vd_start(int dir);
+void filer_vd2_start(int dir);
+void filer_vd_add(int dir, char* fname);
+void filer_vd_add2(int dir, char* line);
+void filer_vd_end(int dir);
+
+BOOL filer_add_keycommand(int meta, int key, char* ftype, char* command, char* fname);
+
+void filer_archive_title(int dir, char* title);
 
 int adir();
 int sdir();
 
-void extend_macro(char* p, string_obj* title);
-int make_size_str(char* result, __off64_t size);
 
 #endif
