@@ -13,6 +13,7 @@
 #if defined(HAVE_MIGEMO_H)
 migemo* gMigemo;
 static regex_t* gReg;
+hash_obj* gMigemoCache; // 一文字だけの正規表現のクェリーは重いのでキャッシュする
 #endif
 
 static string_obj* gInputFileName;      // 入力された文字列
@@ -94,44 +95,56 @@ static BOOL match_back(int start)
     if(string_c_str(gInputFileName)[0] != 0) {
         /// get reg ///
         if(gReg == NULL) {
-            OnigUChar* p = migemo_query(gMigemo, (unsigned char*)string_c_str(gInputFileName));
-            if(p == NULL) {
-                return FALSE;
+            regex_t* reg = hash_item(gMigemoCache, (unsigned char*)string_c_str(gInputFileName));
+            if(reg) {
+                gReg = reg;
             }
-
-            int r;
-            OnigErrorInfo err_info;
-
-            OnigUChar* p2 = MALLOC(sizeof(char)*strlen(p)*2);
-            char* p3 = p2;
-            char* p4 = p;
-            while(*p) {
-                if(*p == '+') {
-                    *p3++ = '\\';
-                    *p3++ = *p4++;
+            else {
+                OnigUChar* p = migemo_query(gMigemo, (unsigned char*)string_c_str(gInputFileName));
+                if(p == NULL) {
+                    return FALSE;
                 }
-                else {
-                    *p3++ = *p4++;
+
+                int r;
+                OnigErrorInfo err_info;
+
+                OnigUChar* p2 = MALLOC(sizeof(char)*strlen(p)*2);
+                char* p3 = p2;
+                char* p4 = p;
+                while(*p) {
+                    if(*p == '+') {
+                        *p3++ = '\\';
+                        *p3++ = *p4++;
+                    }
+                    else {
+                        *p3++ = *p4++;
+                    }
                 }
-            }
-            *p3 = 0;
+                *p3 = 0;
 
-            if(gKanjiCode == kUtf8) {
-                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_UTF8, ONIG_SYNTAX_DEFAULT,  &err_info);
-            }
-            else if(gKanjiCode == kEucjp) {
-                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_EUC_JP, ONIG_SYNTAX_DEFAULT, &err_info);
-            }
-            else if(gKanjiCode == kSjis) {
-                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_SJIS, ONIG_SYNTAX_DEFAULT, &err_info);
-            }
+                if(gKanjiCode == kUtf8) {
+                    r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_UTF8, ONIG_SYNTAX_DEFAULT,  &err_info);
+                }
+                else if(gKanjiCode == kEucjp) {
+                    r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_EUC_JP, ONIG_SYNTAX_DEFAULT, &err_info);
+                }
+                else if(gKanjiCode == kSjis) {
+                    r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_SJIS, ONIG_SYNTAX_DEFAULT, &err_info);
+                }
 
-            FREE(p2);
+                FREE(p2);
 
-            migemo_release(gMigemo, (unsigned char*) p);
+                migemo_release(gMigemo, (unsigned char*) p);
 
-            if(r != ONIG_NORMAL) {
-                return FALSE;
+                if(r != ONIG_NORMAL) {
+                    return FALSE;
+                }
+
+                /// 一文字だけの正規表現は重いのでキャッシュする
+                unsigned char* p5 = string_c_str(gInputFileName);
+                if(strlen(p5) == 1 && *p5 >= 'A' && *p5 <= 'z') {
+                    hash_put(gMigemoCache, (unsigned char*)string_c_str(gInputFileName), gReg);
+                }
             }
         }
 
@@ -157,8 +170,6 @@ static BOOL match_back(int start)
                     || gISearchPartMatch && result != NULL)
                 {
                     filer_cursor_move(adir(), i);
-                    //if(gReg) onig_free(gReg);
-                    //gReg = NULL;
                     
                     return TRUE;
                 }
@@ -177,15 +188,10 @@ static BOOL match_back(int start)
                     || gISearchPartMatch && r2 >= 0)
                 {
                     filer_cursor_move(adir(), i);
-                    //if(gReg) onig_free(gReg);
-                    //gReg = NULL;
                     return TRUE;
                 }
             }
         }
-
-        //if(gReg) onig_free(gReg);
-        //gReg = NULL;
     }
 
     return FALSE;
@@ -219,42 +225,54 @@ static BOOL match_next(int start)
     if(string_c_str(gInputFileName)[0] != 0) {
         /// get reg ///
         if(gReg == NULL) {
-            OnigUChar* p = migemo_query(gMigemo, (unsigned char*)string_c_str(gInputFileName));
-            if(p == NULL) {
-                return FALSE;
-            }
-
-            OnigUChar* p2 = MALLOC(strlen(p)*2);
-            char* p3 = p2;
-            char* p4 = p;
-            while(*p4) {
-                if(*p4 == '+') {
-                    *p3++ = '\\';
-                    *p3++ = *p4++;
-                }
-                else {
-                    *p3++ = *p4++;
-                }
-            }
-            *p3 = 0;
-
-            int r;
-            OnigErrorInfo err_info;
-
-            if(gKanjiCode == kUtf8) {
-                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_UTF8, ONIG_SYNTAX_DEFAULT,  &err_info);
-            }
-            else if(gKanjiCode == kEucjp) {
-                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_EUC_JP, ONIG_SYNTAX_DEFAULT, &err_info);
+            regex_t* reg = hash_item(gMigemoCache, (unsigned char*)string_c_str(gInputFileName));
+            if(reg) {
+                gReg = reg;
             }
             else {
-                r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_SJIS, ONIG_SYNTAX_DEFAULT, &err_info);
-            }
-            FREE(p2);
-            migemo_release(gMigemo, (unsigned char*) p);
+                OnigUChar* p = migemo_query(gMigemo, (unsigned char*)string_c_str(gInputFileName));
+                if(p == NULL) {
+                    return FALSE;
+                }
 
-            if(r != ONIG_NORMAL) {
-                return FALSE;
+                OnigUChar* p2 = MALLOC(strlen(p)*2);
+                char* p3 = p2;
+                char* p4 = p;
+                while(*p4) {
+                    if(*p4 == '+') {
+                        *p3++ = '\\';
+                        *p3++ = *p4++;
+                    }
+                    else {
+                        *p3++ = *p4++;
+                    }
+                }
+                *p3 = 0;
+
+                int r;
+                OnigErrorInfo err_info;
+
+                if(gKanjiCode == kUtf8) {
+                    r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_UTF8, ONIG_SYNTAX_DEFAULT,  &err_info);
+                }
+                else if(gKanjiCode == kEucjp) {
+                    r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_EUC_JP, ONIG_SYNTAX_DEFAULT, &err_info);
+                }
+                else {
+                    r = onig_new(&gReg, p2, p2 + strlen((char*)p2), ONIG_OPTION_DEFAULT, ONIG_ENCODING_SJIS, ONIG_SYNTAX_DEFAULT, &err_info);
+                }
+                FREE(p2);
+                migemo_release(gMigemo, (unsigned char*) p);
+
+                if(r != ONIG_NORMAL) {
+                    return FALSE;
+                }
+
+                /// 一文字だけの正規表現は重いのでキャッシュする
+                unsigned char* p5 = string_c_str(gInputFileName);
+                if(strlen(p5) == 1 && *p5 >= 'A' && *p5 <= 'z') {
+                    hash_put(gMigemoCache, (unsigned char*)string_c_str(gInputFileName), gReg);
+                }
             }
         }
 
@@ -281,8 +299,6 @@ static BOOL match_next(int start)
                     || gISearchPartMatch && result != NULL)
                 {
                     filer_cursor_move(adir(), i);
-                    //if(gReg) onig_free(gReg);
-                    //gReg = NULL;
                     
                     return TRUE;
                 }
@@ -301,15 +317,10 @@ static BOOL match_next(int start)
                     || gISearchPartMatch && r2 >= 0)
                 {
                     filer_cursor_move(adir(), i);
-                    //if(gReg) onig_free(gReg);
-                    //gReg = NULL;
                     return TRUE;
                 }
             }
         }
-
-        //if(gReg) onig_free(gReg);
-        //gReg = NULL;
     }
 
     return FALSE;
@@ -404,6 +415,7 @@ void isearch_init()
 #if defined(HAVE_MIGEMO_H)
     gReg = NULL;
     migemo_init();
+    gMigemoCache = HASH_NEW(100);
 #endif
 
 }
@@ -418,8 +430,16 @@ void isearch_final()
 #if defined(HAVE_MIGEMO_H)
     onig_end();
     migemo_close(gMigemo);
-    if(gReg) onig_free(gReg);
+    if(gReg && hash_key(gMigemoCache, gReg) == NULL) onig_free(gReg);
     gReg = NULL;
+    hash_it* it = hash_loop_begin(gMigemoCache);
+    while(!it) {
+        regex_t* reg  = hash_loop_item(it);
+        onig_free(reg);
+
+        it = hash_loop_next(it);
+    }
+    hash_delete(gMigemoCache);
 #endif
 }
 
@@ -430,10 +450,14 @@ void isearch_input(int meta, int key)
 {
     if(key == 8 || key == KEY_BACKSPACE || key == KEY_DC) {
         string_erase(gInputFileName, string_length(gInputFileName)-1, 1);
-
 #if defined(HAVE_MIGEMO_H)
-        if(gReg) onig_free(gReg);
-        gReg = NULL;
+        if(gReg && hash_key(gMigemoCache, gReg) == NULL) {
+            onig_free(gReg);
+            gReg = NULL;
+        }
+        else {
+            gReg = NULL;
+        }
 #endif
     }
     else if(key == 14 || key == KEY_DOWN) {
@@ -472,10 +496,14 @@ void isearch_input(int meta, int key)
         gISearch = FALSE;
         gISearchPartMatch = FALSE;
         string_put(gInputFileName, "");
-
 #if defined(HAVE_MIGEMO_H)
-        if(gReg) onig_free(gReg);
-        gReg = NULL;
+        if(gReg && hash_key(gMigemoCache, gReg) == NULL) {
+            onig_free(gReg);
+            gReg = NULL;
+        }
+        else {
+            gReg = NULL;
+        }
 #endif
     }
     else {
@@ -485,8 +513,13 @@ void isearch_input(int meta, int key)
             string_push_back2(gInputFileName, (char)key);
 
 #if defined(HAVE_MIGEMO_H)
-                if(gReg) onig_free(gReg);
-                gReg = NULL;
+        if(gReg && hash_key(gMigemoCache, gReg) == NULL) {
+            onig_free(gReg);
+            gReg = NULL;
+        }
+        else {
+            gReg = NULL;
+        }
 #endif
 
         if(gISearchOption1 && !gISearchPartMatch) {
@@ -497,8 +530,13 @@ void isearch_input(int meta, int key)
                     string_erase(gInputFileName, string_length(gInputFileName)-1, 1);
 
 #if defined(HAVE_MIGEMO_H)
-                    if(gReg) onig_free(gReg);
-                    gReg = NULL;
+                    if(gReg && hash_key(gMigemoCache, gReg) == NULL) {
+                        onig_free(gReg);
+                        gReg = NULL;
+                    }
+                    else {
+                        gReg = NULL;
+                    }
 #endif
                 }
 
@@ -509,10 +547,15 @@ void isearch_input(int meta, int key)
             if(!match_next(0)) {
                 string_erase(gInputFileName, string_length(gInputFileName)-1, 1);
 
-    #if defined(HAVE_MIGEMO_H)
-                    if(gReg) onig_free(gReg);
+#if defined(HAVE_MIGEMO_H)
+                if(gReg && hash_key(gMigemoCache, gReg) == NULL) {
+                    onig_free(gReg);
                     gReg = NULL;
-    #endif
+                }
+                else {
+                    gReg = NULL;
+                }
+#endif
             }
         }
     }
@@ -554,10 +597,15 @@ void isearch_explore_input(int meta, int key)
     else {
         string_push_back2(gInputFileName, (char)key);
 
-    #if defined(HAVE_MIGEMO_H)
-        if(gReg) onig_free(gReg);
-        gReg = NULL;
-    #endif
+#if defined(HAVE_MIGEMO_H)
+        if(gReg && hash_key(gMigemoCache, gReg) == NULL) {
+            onig_free(gReg);
+            gReg = NULL;
+        }
+        else {
+            gReg = NULL;
+        }
+#endif
 
         if(gISearchOption1 && !gISearchPartMatch) {
             if(!match_next(0)) {
@@ -568,8 +616,13 @@ void isearch_explore_input(int meta, int key)
                     string_push_back2(gInputFileName, (char)key);
 
 #if defined(HAVE_MIGEMO_H)
-                    if(gReg) onig_free(gReg);
-                    gReg = NULL;
+                    if(gReg && hash_key(gMigemoCache, gReg) == NULL) {
+                        onig_free(gReg);
+                        gReg = NULL;
+                    }
+                    else {
+                        gReg = NULL;
+                    }
 #endif
                     if(!match_next(0)) {
                         string_put(gInputFileName, "");
@@ -585,8 +638,13 @@ void isearch_explore_input(int meta, int key)
                 string_push_back2(gInputFileName, (char)key);
 
 #if defined(HAVE_MIGEMO_H)
-                if(gReg) onig_free(gReg);
-                gReg = NULL;
+                if(gReg && hash_key(gMigemoCache, gReg) == NULL) {
+                    onig_free(gReg);
+                    gReg = NULL;
+                }
+                else {
+                    gReg = NULL;
+                }
 #endif
                 if(!match_next(0)) {
                     string_put(gInputFileName, "");
