@@ -56,9 +56,11 @@
 
 #endif
 
+#if !defined(__DARWIN__)
 extern int kill (__pid_t __pid, int __sig) __THROW;
 extern int setenv(const char *name, const char *value, int overwrite);
 extern void srandom (unsigned int __seed) __THROW;
+#endif
 
 BOOL gMainLoop = FALSE;
 void (*gView)() = NULL;          // 登録描写関数
@@ -887,7 +889,7 @@ int main(int argc, char* argv[])
     CHECKML_BEGIN();
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.1.1", 1);
+    setenv("VERSION", "4.1.5", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -1180,21 +1182,29 @@ int main(int argc, char* argv[])
     read_rc_file_compiled();
 
     /// ディレクトリを作成 ///
-    if(vector_size(gDirs) == 0) {
+    if(vector_size(gDirs) < 0) {
         if(strcmp(file_name, "") == 0) {
             char cwd[PATH_MAX];
             mygetcwd(cwd);
 
-            filer_new_dir(cwd);
-            filer_cd(0, string_c_str(filer_dir(0)->mPath));
-            filer_new_dir(cwd);
-            filer_cd(1, string_c_str(filer_dir(1)->mPath));
+            if(filer_new_dir(cwd, FALSE, ".+") < 0) {
+                fprintf(stderr, "invalid current directory\n");
+                exit(1);
+            }
+            if(filer_new_dir(cwd, FALSE, ".+") < 0) {
+                fprintf(stderr, "invalid current directory\n");
+                exit(1);
+            }
         }
         else {
-            filer_new_dir(file_name);
-            filer_cd(0, string_c_str(filer_dir(0)->mPath));
-            filer_new_dir(file_name);
-            filer_cd(1, string_c_str(filer_dir(1)->mPath));
+            if(filer_new_dir(file_name, FALSE, ".+") < 0) {
+                fprintf(stderr, "invalid directory(%s)\n", file_name);
+                exit(1);
+            }
+            if(filer_new_dir(file_name, FALSE, ".+") < 0) {
+                fprintf(stderr, "invalid directory(%s)\n", file_name);
+                exit(1);
+            }
         }
     }
     else if(vector_size(gDirs) == 1) {
@@ -1202,12 +1212,16 @@ int main(int argc, char* argv[])
             char cwd[PATH_MAX];
             mygetcwd(cwd);
 
-            filer_new_dir(cwd);
-            filer_cd(0, string_c_str(filer_dir(0)->mPath));
+            if(filer_new_dir(cwd, FALSE, ".+") < 0) {
+                fprintf(stderr, "invalid current directory\n");
+                exit(1);
+            }
         }
         else {
-            filer_new_dir(file_name);
-            filer_cd(0, string_c_str(filer_dir(0)->mPath));
+            if(filer_new_dir(file_name, FALSE, ".+") < 0) {
+                fprintf(stderr, "invalid directory(%s)\n", file_name);
+                exit(1);
+            }
         }
     }
 
